@@ -621,6 +621,19 @@ def test_get_atac_chip_pipeline_replicate(mocker, mock_accession_chip, gsfile):
     assert rep == "rep1"
 
 
+def test_get_atac_chip_pipeline_replicate_control(mocker, mock_accession_chip, gsfile):
+    mocker.patch.object(
+        mock_accession_chip.analysis, "search_up", return_value=[gsfile]
+    )
+    mocker.patch.object(
+        mock_accession_chip.analysis.metadata,
+        "content",
+        {"inputs": {"ctl_fastqs_rep1_R1": ["gs://abc/spam.fastq.gz"]}},
+    )
+    rep = mock_accession_chip.get_atac_chip_pipeline_replicate(gsfile)
+    assert rep == "ctl1"
+
+
 def test_get_atac_chip_pipeline_replicate_raises(mocker, mock_accession_chip, gsfile):
     mocker.patch.object(
         mock_accession_chip.analysis, "search_up", return_value=[gsfile]
